%define module_name SQLAlchemy

Summary:	SQL toolkit and object relational mapper for Python
Name:		python-sqlalchemy
Version:	0.8.2
Release:	%mkrel 3
License:	MIT
Group:		Development/Python
URL:		http://www.sqlalchemy.org/
Source0:	http://pypi.python.org/packages/source/S/%{module_name}/%{module_name}-%{version}.tar.gz
Patch0: sqlalchemy-nose-use-build.patch

BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildRequires:	python-setuptools
BuildRequires:	python-nose
BuildRequires:	python-mock
BuildRequires:	pkgconfig(python)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-setuptools
BuildRequires:	python3-nose
BuildRequires:	python3-mock

%description
%{module_name} is an Object Relational Mappper (ORM) that provides a flexible,
high-level interface to SQL databases.  Database and domain concepts are
decoupled, allowing both sides maximum flexibility and power. SQLAlchemy
provides a powerful mapping layer that can work as automatically or as manually
as you choose, determining relationships based on foreign keys or letting you
define the join conditions explicitly, to bridge the gap between database and
domain.
This package includes the python 2 version of the module.

%package -n python3-sqlalchemy
Summary:	Modular and flexible ORM library for python
Group:		Development/Python

%description -n python3-sqlalchemy
SQLAlchemy is an Object Relational Mappper (ORM) that provides a flexible,
high-level interface to SQL databases.  Database and domain concepts are
decoupled, allowing both sides maximum flexibility and power. SQLAlchemy
provides a powerful mapping layer that can work as automatically or as manually
as you choose, determining relationships based on foreign keys or letting you
define the join conditions explicitly, to bridge the gap between database and
domain.

This package includes the python 3 version of the module.

%prep
%setup -q -n %{module_name}-%{version}
%patch0 -p0

rm -rf %{py3dir}
cp -a . %{py3dir}

%build
CFLAGS="%{optflags}" %{__python} setup.py --with-cextensions build

pushd %{py3dir}
# Convert tests and examples to python3
%{__python3} sa2to3.py --no-diffs -w test examples
# Currently the cextension doesn't work with python3
CFLAGS="%{optflags}" %{__python3} setup.py build
popd

%install
mkdir -p %{buildroot}%{python_sitelib}
%{__python} setup.py --with-cextensions install --skip-build --root %{buildroot}

pushd %{py3dir}
mkdir -p %{buildroot}%{python3_sitelib}
# Currently the cextension doesn't work with python3
%{__python3} setup.py install --skip-build --root %{buildroot}
popd

# remove unnecessary scripts for building documentation
rm -rf doc/build

%check
%{__python} ./sqla_nose.py

pushd %{py3dir}
%{__python3} ./sqla_nose.py
popd

%files
%doc README.rst LICENSE PKG-INFO CHANGES doc examples
%{python_sitearch}/*

%files -n python3-sqlalchemy
%doc LICENSE PKG-INFO doc examples
%{python3_sitelib}/*



%changelog
* Tue Oct 22 2013 umeabot <umeabot> 0.8.2-3.mga4
+ Revision: 544352
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 0.8.2-2.mga4
+ Revision: 499431
- Rebuild to add different pythonegg provides for python 2 and 3

* Wed Jul 10 2013 philippem <philippem> 0.8.2-1.mga4
+ Revision: 452446
- Update to 0.8.2, add Python 3

* Sat Feb 16 2013 philippem <philippem> 0.7.10-1.mga3
+ Revision: 398743
- Update to new upstream

* Sun Jan 13 2013 umeabot <umeabot> 0.7.9-2.mga3
+ Revision: 379545
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 23 2012 philippem <philippem> 0.7.9-1.mga3
+ Revision: 334189
- Update to 0.7.9

* Sat Dec 17 2011 philippem <philippem> 0.7.4-1.mga2
+ Revision: 183152
- Update to 0.7.4

* Fri Nov 18 2011 philippem <philippem> 0.7.3-1.mga2
+ Revision: 168699
- Update to 0.7.3

* Wed Sep 21 2011 philippem <philippem> 0.7.2-1.mga2
+ Revision: 146407
- 0.7.2 Upstream release
- use sqla_nose.py to fix %%check

* Fri Apr 08 2011 philippem <philippem> 0.6.6-1.mga1
+ Revision: 82011
- imported package python-sqlalchemy


* Thu Apr 07 2011 Philippe Makowski <makowski.mageia@gmail.com> 0.6.6-1mga1
- Update to 0.6.6
- Add cextensions
- Imported from Mandriva

* Mon Nov 01 2010 Funda Wang <fwang@mandriva.org> 0.6.4-3mdv2011.0
+ Revision: 591429
- rebuild for py 2.7

* Sat Oct 30 2010 Michael Scherer <misc@mandriva.org> 0.6.4-2mdv2011.0
+ Revision: 590593
- rebuild for python 2.7

* Tue Sep 07 2010 Lev Givon <lev@mandriva.org> 0.6.4-1mdv2011.0
+ Revision: 576682
- Update to 0.6.4.
- Update to 0.6.2.
- Update to 0.6.1.

* Mon Jan 18 2010 Frederik Himpe <fhimpe@mandriva.org> 0.5.8-1mdv2010.1
+ Revision: 493276
- update to new version 0.5.8

* Tue Dec 29 2009 Frederik Himpe <fhimpe@mandriva.org> 0.5.7-1mdv2010.1
+ Revision: 483307
- update to new version 0.5.7

* Mon Sep 14 2009 Lev Givon <lev@mandriva.org> 0.5.6-1mdv2010.0
+ Revision: 441080
- Update to 0.5.6.

* Tue Jul 14 2009 Frederik Himpe <fhimpe@mandriva.org> 0.5.5-1mdv2010.0
+ Revision: 396016
- update to new version 0.5.5

* Wed May 27 2009 Frederik Himpe <fhimpe@mandriva.org> 0.5.4p2-1mdv2010.0
+ Revision: 380279
- update to new version 0.5.4p2

* Mon May 18 2009 Frederik Himpe <fhimpe@mandriva.org> 0.5.4p1-1mdv2010.0
+ Revision: 377349
- update to new version 0.5.4p1

* Sat May 02 2009 Frederik Himpe <fhimpe@mandriva.org> 0.5.3-1mdv2010.0
+ Revision: 370658
- update to new version 0.5.3

* Sun Mar 15 2009 Michael Scherer <misc@mandriva.org> 0.5.2-1mdv2009.1
+ Revision: 355347
- update to new version
- do not hardcode the module name everywhere
- use a different source url to ease update with mdvsys

* Fri Jan 02 2009 Funda Wang <fwang@mandriva.org> 0.4.8-2mdv2009.1
+ Revision: 323373
- rebuild

* Thu Nov 13 2008 Oden Eriksson <oeriksson@mandriva.com> 0.4.8-1mdv2009.1
+ Revision: 302684
- 0.4.8

* Thu Sep 04 2008 Jérôme Soyer <saispo@mandriva.org> 0.4.7p1-1mdv2009.0
+ Revision: 280565
- New version

* Fri Aug 08 2008 Thierry Vignaud <tv@mandriva.org> 0.4.6-2mdv2009.0
+ Revision: 269043
- rebuild early 2009.0 package (before pixel changes)

* Wed Jun 11 2008 Lev Givon <lev@mandriva.org> 0.4.6-1mdv2009.0
+ Revision: 218094
- Update to 0.4.6.

* Thu Feb 21 2008 Oden Eriksson <oeriksson@mandriva.com> 0.3.11-1mdv2008.1
+ Revision: 173632
- fix build deps (duh!)
- import python-sqlalchemy


* Thu Feb 21 2008 Oden Eriksson <oeriksson@mandriva.com> 0.3.11-1mdv2008.1
- initial Mandriva package

* Sun Jan 20 2008 Oden Eriksson <oeriksson@mandriva.com> 0.3.11-1.RHEL4
- initial Redhat RHEL4 package.
